@@ -15,7 +15,7 @@
 ##  along with this program; if not, write to the Free Software
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##
-##  $Id: runitRUnit.r,v 1.13 2007/05/16 12:16:47 burgerm Exp $
+##  $Id: runitRUnit.r,v 1.15 2007/11/30 14:13:56 burgerm Exp $
 
 
 cat("\n\nRUnit test cases for 'RUnit:check' functions\n\n")
@@ -38,11 +38,19 @@ testRUnit.checkEquals <- function()
   checkEquals(namedInt, x, checkNames=FALSE)
   
   ##  numeric
-  checkEquals(9,9)
+  y <- 1/0
+  checkEquals(Inf, y)
+  checkEquals(y, Inf)
+  y <- log(-1)
+  checkEquals(NaN, y)
+  checkEquals(rep(NaN, 23), rep(y, 23))
+  checkEquals(9, 9.0)
+  checkEquals(NA, NA)
+  checkEquals(rep(NA, 14), rep(NA, 14))
   checkEquals( numeric(1), numeric(1))
-  checkEquals( 0.01, 0.02, tol=0.01)
+  checkEquals( 0.01, 0.02, tolerance=0.01)
   tmp <- c(0.01, NA, 0.02, Inf, -Inf, NaN, 1.0)
-  checkEquals( tmp, tmp, tol=0.01)
+  checkEquals( tmp, tmp, tolerance=0.01)
   
   ##  complex
   checkEquals(complex(0), complex(0))
@@ -76,8 +84,8 @@ testRUnit.checkEquals <- function()
   
   ##  list
   checkEquals( list(100), list(100))
-  checkEquals( list(100), list(100), tol=1)
-  alphaList <- seq(along=letters)
+  checkEquals( list(100), list(100), tolerance=1)
+  alphaList <- seq_along(letters)
   names(alphaList) <- letters
   checkEquals( alphaList, alphaList)
   checkEquals( alphaList, alphaList, checkNames=FALSE)
@@ -130,9 +138,9 @@ testRUnit.checkEquals <- function()
 
   
   ##  exception handling
-  checkException( checkEquals(1 , 1, tol=FALSE))
-  checkException( checkEquals(1 , 1, tol=numeric(0)))
-  checkException( checkEquals(1 , 1, tol=numeric(2)))
+  checkException( checkEquals(1 , 1, tolerance=FALSE))
+  checkException( checkEquals(1 , 1, tolerance=numeric(0)))
+  checkException( checkEquals(1 , 1, tolerance=numeric(2)))
 
   ##  integer
   namedInt <- 1:9
@@ -141,28 +149,36 @@ testRUnit.checkEquals <- function()
   
   ##  numeric
   checkException( checkEquals( 8, 9))
-  checkException( checkEquals( 0.01, 0.02, tol=0.009))
+  checkException( checkEquals( 0.01, 0.02, tolerance=0.009))
+  checkException(checkEquals(NaN, NA))
+  checkException(checkEquals(NaN, Inf))
+  checkException(checkEquals(NaN, -Inf))
+  checkException(checkEquals(NA, Inf))
+  checkException(checkEquals(NA, -Inf))
+  checkException(checkEquals(numeric(2), numeric(3)))
+  checkException(checkEquals(numeric(3), numeric(2)))
   
   ##  complex
   checkException( checkEquals(complex(0), complex(1)))
-  checkException( checkEquals(complex(1), complex(2)))
+  checkException( checkEquals(complex(2), complex(1)))
   checkException( checkEquals(complex(2, imaginary=1), complex(2, imaginary=0)))
   checkException( checkEquals(complex(2, real=1, imaginary=1), complex(2, real=1, imaginary=0)))
   checkException( checkEquals(complex(2, real=1, imaginary=1), complex(2, real=0, imaginary=1)))
   checkException( checkEquals(complex(2, real=1, imaginary=1), complex(2, real=0, imaginary=0)))
-
+  
   ##  character
   named <- character(1)
   names(named) <- "name"
   checkException( checkEquals( character(1), named))
-
+  checkException( checkEquals( letters, letters[-1]))
+  
   ##  formula
   checkException( checkEquals( lmFit, lmFitUnnamed))
   lmFitInter <- glm(counts ~ outcome * treatment, family=poisson())
   checkException( checkEquals( lmFitInter, lmFit))
   
   ##  factor
-  alphaFacRecoded <- factor(alphaFac, labels=as.character(seq(along=levels(alphaFac))))
+  alphaFacRecoded <- factor(alphaFac, labels=as.character(seq_along(levels(alphaFac))))
   checkException( checkEquals(alphaFacRecoded, alphaFac))
   
   ##  list
@@ -208,7 +224,7 @@ testRUnit.checkEqualsNumeric <- function()
   ##@edescr
 
   checkTrue( checkEqualsNumeric( 9,9))
-  checkTrue( checkEqualsNumeric( 9.1,9.2, tol=0.1))
+  checkTrue( checkEqualsNumeric( 9.1,9.2, tolerance=0.1))
   x <- 1:10
   attributes(x) <- list(dummy="nonsense")
   checkTrue( checkEqualsNumeric( x, x))
@@ -360,10 +376,10 @@ testRUnit.checkException <- function()
   checkException( checkTrue( ))
   checkException( checkEquals( ))
   checkException( checkEquals( 24))
-  checkException( checkEquals( 24, 24, tol="dummy"))
+  checkException( checkEquals( 24, 24, tolerance="dummy"))
   checkException( checkEqualsNumeric( ))
   checkException( checkEqualsNumeric( 24))
-  checkException( checkEqualsNumeric( 24, 24, tol="dummy"))
+  checkException( checkEqualsNumeric( 24, 24, tolerance="dummy"))
 
   checkException( stop("with message"), silent=FALSE)
   checkException( stop("wo message"), silent=TRUE)
